==============================
Exolib
==============================

Rebin
---------------------

.. autoclass:: exorad.utils.exolib.rebin
    :members:
    :undoc-members:
    :show-inheritance:

Planck
---------------------

.. autoclass:: exorad.utils.exolib.planck
    :members:
    :undoc-members:
    :show-inheritance:

OmegaPix
---------------------

.. autoclass:: exorad.utils.exolib.OmegaPix
    :members:
    :undoc-members:
    :show-inheritance:

